==> eam-wshub-proxyclient-11.4-5-sources.jar: org/openapplications/oagis_fields/VERB.java <==

package org.openapplications.oagis_fields;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour VERB.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * <p>
 * <pre>
 * &lt;simpleType name="VERB">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="Acknowledge"/>
 *     &lt;enumeration value="Allocate"/>
 *     &lt;enumeration value="Add"/>
 *     &lt;enumeration value="Cancel"/>
 *     &lt;enumeration value="Change"/>
 *     &lt;enumeration value="Confirm"/>
 *     &lt;enumeration value="Create"/>
 *     &lt;enumeration value="Get"/>
 *     &lt;enumeration value="Getlist"/>
 *     &lt;enumeration value="Issue"/>
 *     &lt;enumeration value="List"/>
 *     &lt;enumeration value="Load"/>
 *     &lt;enumeration value="Post"/>
 *     &lt;enumeration value="Process"/>
 *     &lt;enumeration value="Receive"/>
 *     &lt;enumeration value="Respond"/>
 *     &lt;enumeration value="Show"/>
 *     &lt;enumeration value="Sync"/>
 *     &lt;enumeration value="Transfer"/>
 *     &lt;enumeration value="Update"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "VERB")
@XmlEnum
public enum VERB {

    @XmlEnumValue("Acknowledge")
    ACKNOWLEDGE("Acknowledge"),
    @XmlEnumValue("Allocate")
    ALLOCATE("Allocate"),
    @XmlEnumValue("Add")
    ADD("Add"),
    @XmlEnumValue("Cancel")
    CANCEL("Cancel"),
    @XmlEnumValue("Change")
    CHANGE("Change"),
    @XmlEnumValue("Confirm")
    CONFIRM("Confirm"),
    @XmlEnumValue("Create")
    CREATE("Create"),
    @XmlEnumValue("Get")
    GET("Get"),
    @XmlEnumValue("Getlist")
    GETLIST("Getlist"),
    @XmlEnumValue("Issue")
    ISSUE("Issue"),
    @XmlEnumValue("List")
    LIST("List"),
    @XmlEnumValue("Load")
    LOAD("Load"),
    @XmlEnumValue("Post")
    POST("Post"),
    @XmlEnumValue("Process")
    PROCESS("Process"),
    @XmlEnumValue("Receive")
    RECEIVE("Receive"),
    @XmlEnumValue("Respond")
    RESPOND("Respond"),
    @XmlEnumValue("Show")
    SHOW("Show"),
    @XmlEnumValue("Sync")
    SYNC("Sync"),
    @XmlEnumValue("Transfer")
    TRANSFER("Transfer"),
    @XmlEnumValue("Update")
    UPDATE("Update");
    private final String value;

    VERB(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static VERB fromValue(String v) {
        for (VERB c: VERB.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: org/openapplications/oagis_fields/VERB.java <==

package org.openapplications.oagis_fields;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for VERB.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="VERB">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="Acknowledge"/>
 *     &lt;enumeration value="Allocate"/>
 *     &lt;enumeration value="Add"/>
 *     &lt;enumeration value="Cancel"/>
 *     &lt;enumeration value="Change"/>
 *     &lt;enumeration value="Confirm"/>
 *     &lt;enumeration value="Create"/>
 *     &lt;enumeration value="Get"/>
 *     &lt;enumeration value="Getlist"/>
 *     &lt;enumeration value="Issue"/>
 *     &lt;enumeration value="List"/>
 *     &lt;enumeration value="Load"/>
 *     &lt;enumeration value="Post"/>
 *     &lt;enumeration value="Process"/>
 *     &lt;enumeration value="Receive"/>
 *     &lt;enumeration value="Respond"/>
 *     &lt;enumeration value="Show"/>
 *     &lt;enumeration value="Sync"/>
 *     &lt;enumeration value="Transfer"/>
 *     &lt;enumeration value="Update"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "VERB")
@XmlEnum
public enum VERB {

    @XmlEnumValue("Acknowledge")
    ACKNOWLEDGE("Acknowledge"),
    @XmlEnumValue("Allocate")
    ALLOCATE("Allocate"),
    @XmlEnumValue("Add")
    ADD("Add"),
    @XmlEnumValue("Cancel")
    CANCEL("Cancel"),
    @XmlEnumValue("Change")
    CHANGE("Change"),
    @XmlEnumValue("Confirm")
    CONFIRM("Confirm"),
    @XmlEnumValue("Create")
    CREATE("Create"),
    @XmlEnumValue("Get")
    GET("Get"),
    @XmlEnumValue("Getlist")
    GETLIST("Getlist"),
    @XmlEnumValue("Issue")
    ISSUE("Issue"),
    @XmlEnumValue("List")
    LIST("List"),
    @XmlEnumValue("Load")
    LOAD("Load"),
    @XmlEnumValue("Post")
    POST("Post"),
    @XmlEnumValue("Process")
    PROCESS("Process"),
    @XmlEnumValue("Receive")
    RECEIVE("Receive"),
    @XmlEnumValue("Respond")
    RESPOND("Respond"),
    @XmlEnumValue("Show")
    SHOW("Show"),
    @XmlEnumValue("Sync")
    SYNC("Sync"),
    @XmlEnumValue("Transfer")
    TRANSFER("Transfer"),
    @XmlEnumValue("Update")
    UPDATE("Update");
    private final String value;

    VERB(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static VERB fromValue(String v) {
        for (VERB c: VERB.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
